aboutsummaryrefslogtreecommitdiff
path: root/azalea-protocol/src/packets/handshake
diff options
context:
space:
mode:
authormat <27899617+mat-1@users.noreply.github.com>2022-07-30 22:57:02 +0000
committerGitHub <noreply@github.com>2022-07-30 22:57:02 +0000
commitbc71c74bef5f82de7224f97a65614251f3ed7cb1 (patch)
tree254a58c1ac77b047df0b86d75d3c6d9dd52c14fc /azalea-protocol/src/packets/handshake
parent060d2f1592b98bca64b2ee15e103aa14db816227 (diff)
parent9ef1e8d653acd7e8e026cbde9c0320cedb8cf1d3 (diff)
downloadazalea-drasl-bc71c74bef5f82de7224f97a65614251f3ed7cb1.tar.xz
Merge pull request #13 from mat-1/split-clientbound-serverbound
Split clientbound and serverbound packets
Diffstat (limited to 'azalea-protocol/src/packets/handshake')
-rwxr-xr-xazalea-protocol/src/packets/handshake/client_intention_packet.rs4
-rwxr-xr-xazalea-protocol/src/packets/handshake/mod.rs6
2 files changed, 5 insertions, 5 deletions
diff --git a/azalea-protocol/src/packets/handshake/mod.rs b/azalea-protocol/src/packets/handshake/mod.rs
index 88d9939b..8fd12529 100755
--- a/azalea-protocol/src/packets/handshake/mod.rs
+++ b/azalea-protocol/src/packets/handshake/mod.rs
@@ -4,8 +4,8 @@ use packet_macros::declare_state_packets;
declare_state_packets!(
HandshakePacket,
- Serverbound => {},
- Clientbound => {
+ Serverbound => {
0x00: client_intention_packet::ClientIntentionPacket,
- }
+ },
+ Clientbound => {}
);
diff --git a/azalea-protocol/src/packets/handshake/client_intention_packet.rs b/azalea-protocol/src/packets/handshake/client_intention_packet.rs
index 5f1987e2..ef47bba3 100755
--- a/azalea-protocol/src/packets/handshake/client_intention_packet.rs
+++ b/azalea-protocol/src/packets/handshake/client_intention_packet.rs
@@ -1,9 +1,9 @@
use crate::packets::ConnectionProtocol;
use azalea_buf::McBuf;
-use packet_macros::HandshakePacket;
+use packet_macros::ServerboundHandshakePacket;
use std::hash::Hash;
#[derive(Hash, Clone, Debug, McBuf, HandshakePacket)]
pub struct ClientIntentionPacket {
#[var]
pub protocol_version: u32,
@@ -1,9 +1,9 @@
use std::hash::Hash;
-#[derive(Hash, Clone, Debug, McBuf, HandshakePacket)]
+#[derive(Hash, Clone, Debug, McBuf, ServerboundHandshakePacket)]
pub struct ClientIntentionPacket {
#[var]